Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(76)

Unified Diff: third_party/boto/boto/kinesis/layer1.py

Issue 698893003: Update checked in version of gsutil to version 4.6 (Closed) Base URL: http://dart.googlecode.com/svn/third_party/gsutil/
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/boto/boto/kinesis/__init__.py ('k') | third_party/boto/boto/mturk/connection.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/boto/boto/kinesis/layer1.py
===================================================================
--- third_party/boto/boto/kinesis/layer1.py (revision 33376)
+++ third_party/boto/boto/kinesis/layer1.py (working copy)
@@ -532,11 +532,10 @@
placed and the sequence number that was assigned to the data
record.
- The `SequenceNumberForOrdering` sets the initial sequence
- number for the partition key. Later `PutRecord` requests to
- the same partition key (from the same client) will
- automatically increase from `SequenceNumberForOrdering`,
- ensuring strict sequential ordering.
+ Sequence numbers generally increase over time. To guarantee
+ strictly increasing ordering, use the
+ `SequenceNumberForOrdering` parameter. For more information,
+ see the `Amazon Kinesis Developer Guide`_.
If a `PutRecord` request cannot be processed because of
insufficient provisioned throughput on the shard involved in
@@ -550,8 +549,10 @@
:param stream_name: The name of the stream to put the data record into.
:type data: blob
- :param data: The data blob to put into the record, which will be Base64
- encoded. The maximum size of the data blob is 50 kilobytes (KB).
+ :param data: The data blob to put into the record, which is
+ Base64-encoded when the blob is serialized.
+ The maximum size of the data blob (the payload after
+ Base64-decoding) is 50 kilobytes (KB)
Set `b64_encode` to disable automatic Base64 encoding.
:type partition_key: string
@@ -571,10 +572,12 @@
partition key hash.
:type sequence_number_for_ordering: string
- :param sequence_number_for_ordering: The sequence number to use as the
- initial number for the partition key. Subsequent calls to
- `PutRecord` from the same client and for the same partition key
- will increase from the `SequenceNumberForOrdering` value.
+ :param sequence_number_for_ordering: Guarantees strictly increasing
+ sequence numbers, for puts from the same client and to the same
+ partition key. Usage: set the `SequenceNumberForOrdering` of record
+ n to the sequence number of record n-1 (as returned in the
+ PutRecordResult when putting record n-1 ). If this parameter is not
+ set, records will be coarsely ordered based on arrival time.
:type b64_encode: boolean
:param b64_encode: Whether to Base64 encode `data`. Can be set to
« no previous file with comments | « third_party/boto/boto/kinesis/__init__.py ('k') | third_party/boto/boto/mturk/connection.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698